@@ -383,6 +383,14 @@ public class MessagePackParser
                 return stringValue;
             case BYTES:
                 return new String(bytesValue, MessagePack.UTF8);
+            case INT:
+                return String.valueOf(intValue);
+            case LONG:
+                return String.valueOf(longValue);
+            case DOUBLE:
+                return String.valueOf(doubleValue);
+            case BIG_INT:
+                return String.valueOf(biValue);
             default:
                 throw new IllegalStateException("Invalid type=" + type);
         }
